//
//  AccelScene.cpp
//  layer_accelerometer
//
//  Created by Reza Ghobadinic on 2019-10-29.
//

#include "AccelScene.h"
#include <iostream>

USING_NS_CC;
using namespace std;

Scene* AccelScene::createScene()
{
    auto scene = Scene::create();
    auto layer = AccelScene::create();
    
    scene->addChild(layer);
    
    return scene;
}

bool AccelScene::init()
{
    // Setup the ball sprite
    auto visibleSize = Director::getInstance()->getVisibleSize();
    Vec2 origin = Director::getInstance()->getVisibleOrigin();
    
    float x = origin.x + visibleSize.width / 2;
    float y = origin.y + visibleSize.height / 2;
     
    auto ball = Sprite::create("ball.png");
    ball->setVisible(true);
    ball->setPosition(x, y);
    this->addChild(ball);
    
    // Setup the accelerometer event handler
    Device::setAccelerometerEnabled(true);
    
    // The callback lambda
    function<void(Acceleration*, Event*)> callback = [ball, visibleSize, origin](Acceleration *acceleration, Event *event){
        
        // Update the ball position using the accelerometr x and y values
        float x = ball->getPositionX();
        float y = ball->getPositionY();
        x += (acceleration->x * 10);
        y += (acceleration->y * 10);
        
        // Make sure the ball stays in the screen
        if (x < origin.x) x = origin.x;
        if (y < origin.y) y = origin.y;
        if (x >= (origin.x + visibleSize.width))  x = origin.x + visibleSize.width  - 1;
        if (y >= (origin.y + visibleSize.height)) y = origin.y + visibleSize.height - 1;
        
        // Update the ball position
        ball->setPosition(x, y);
        
        cout << acceleration->timestamp << " " << acceleration->x << " " << acceleration->y << " " << acceleration->z << endl;
    };
    
    auto listener = EventListenerAcceleration::create(callback); // Create an accelerometer listener
    _eventDispatcher->addEventListenerWithSceneGraphPriority(listener, this);
    
    return true;
}
